@@ -14,14 +14,21 @@ def combine_params(*values,typ=None):
             if typ is list:
                 nu_values += typ(value)
     return nu_values
-def get_safe_kwargs(canonical_map,**kwargs):
+def get_safe_kwargs(canonical_map, **kwargs):
     # Lowercase all keys for safety
+    canonical_map = canonical_map or CANONICAL_MAP
     norm_kwargs = {k.lower(): v for k, v in kwargs.items() if v is not None}
-    
-    # Inverse lookup: alias → canonical key
-    alias_lookup = {alias: canon for canon, aliases in canonical_map.items() for alias in aliases}
 
-    safe_kwargs = {k: v for k, v in norm_kwargs.items() if k in canonical_map}  # preserve correctly named keys
+    # Inverse lookup: alias → canonical key
+    alias_lookup = {
+        alias: canon
+        for canon, aliases in canonical_map.items()
+        if aliases
+        for alias in aliases
+    }
+
+    # Preserve correctly named keys
+    safe_kwargs = {k: v for k, v in norm_kwargs.items() if k in canonical_map}
 
     for k, v in norm_kwargs.items():
         if k in alias_lookup:
@@ -39,8 +46,9 @@ def get_safe_kwargs(canonical_map,**kwargs):
     # fill defaults if missing
     for canon in canonical_map:
         safe_kwargs.setdefault(canon, None)
-    #print(f"canonicl_map == {canonical_map}\n\nkwrgs={kwargs}\n\nsafe_kwargs=={safe_kwargs}")
+
     return safe_kwargs
+
 def create_canonical_map(*args,canonical_map=None):
     keys = [arg for arg in args if arg]
     if not keys:
