@@ -100,7 +100,7 @@ def get_find_cmd(
     # Get directory list (may come from args or kwargs)
     directories = [r for r in make_list(kwargs.get("directories")) if r]
     if not directories:
-        raise ValueError("No directories specified for `find` command.")
+        return []
 
     # Build base command for all directories
     dir_expr = " ".join(shlex.quote(d) for d in directories)
@@ -183,7 +183,18 @@ def get_find_cmd(
 
     return " ".join(cmd)
 
-
+def ensure_directories(*args,**kwargs):
+    directories = []
+    for arg in args:
+        arg_str = str(arg)
+        if is_dir(arg_str,**kwargs):
+            directories.append(arg_str)
+        elif is_file(arg_str,**kwargs):
+            dirname = os.path.dirname(arg_str)
+            directories.append(dirname)
+    safe_directories = get_dir_filter_kwargs(**kwargs)
+    directories+= make_list(safe_directories.get('directories',[]))
+    return list(set([r for r in directories if r]))
 
 def collect_globs(
     *args,
@@ -201,9 +212,9 @@ def collect_globs(
     - If file_type is "f" or "d" → returns a list of that type
     - Supports SSH mode via `user_at_host`
     """
-    kwargs= get_safe_canonical_kwargs(*args,**kwargs)
+    directories = ensure_directories(*args, **kwargs)
+    kwargs= get_safe_canonical_kwargs(**kwargs)
     
-    cfg = define_defaults(**kwargs)
     allowed = kwargs.get("allowed") or make_allowed_predicate(cfg)
     type_strs = {"f":"files","d":"dirs"}
     file_type = get_proper_type_str(file_type)
@@ -216,7 +227,7 @@ def collect_globs(
         type_str = type_strs.get(file_type)
         # Remote path (SSH)
         find_cmd = get_find_cmd(
-                cfg=cfg,
+            directories=directories,
                 mindepth=mindepth,
                 maxdepth=maxdepth,
                 depth=depth,
